==> tine20-allinone_2020.08.8.tar.bz2: Timetracker/js/Timetracker-lang-de-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2019-08-20 11:26+0200\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: German (http://www.transifex.com/tine20/tine20/language/de/)\nLanguage: de\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-SourceCharset: utf-8\nX-Generator: Poedit 2.0.6\n"

, "Responsible"
: "Verantwortlich"

, "without responsible"
: "ohne Verantwortlichen"

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: "Zeitkonten schließen"

, "timeframe"
: "Zeitrahmen"

, "summary"
: "Zusammenfassung"

, "Total Timesheets"
: "Alle Stundenzettel"

, "Billable Timesheets"
: "Abrechenbare Stundenzettel"

, "Total Time"
: "Gesamtsumme"

, "Time of Billable Timesheets"
: "Gesamtzeit abrechenbarer Stundenzettel"

, "Description"
: "Beschreibung"

, "Detail"
: "Detail"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: "Stundenzettel exportieren"

, "Export as ODS"
: "Als ODS exportieren"

, "Export as CSV"
: "Als CSV exportieren"

, "Export as ..."
: "Als ... exportieren"

, "Timesheet, Timesheets"
: [
  "Stundenzettel"
 ,"Stundenzettel"

]
, "Accounting"
: ""

, "Timeaccount, Timeaccounts"
: [
  "Zeitkonto"
 ,"Zeitkonten"

]
, "Failed"
: "Fehlgeschlagen"

, "Could not save {0}."
: "Konnte {0} nicht speichern."

, "Booking deadline for this Timeaccount has been exceeded."
: "Die Buchungsfrist für dieses Zeitkonto wurde überschritten."

, "Closed Timeaccount Warning!"
: "Achtung, geschlossenes Zeitkonto!"

, "The selected Time Account is already closed."
: "Das ausgewählte Zeitkonto ist bereits geschlossen."

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: "Das ausgewählte Zeitkonto ist bereits geschlossen. Wollen Sie dennoch fortfahren?"

, "Contract"
: "Vertrag"

, "without contract"
: "ohne Vertrag"

, "Add New Timeaccount"
: "Zeitkonten hinzufügen"

, "Unit"
: "Einheit"

, "Unit Price"
: "Preis einer Einheit"

, "Factor"
: "Faktor"

, "Budget"
: "Budget"

, "Status"
: "Status"

, "closed"
: "geschlossen"

, "open"
: "offen"

, "Cleared In"
: "Abgerechnet in"

, "Cleared at"
: "Abgerechnet am"

, "Cost Center"
: "Kostenstelle"

, "Responsible Person"
: "Verantwortlicher"

, "Timesheets are billable"
: "Stundenzettel sind abrechenbar"

, "Invoice"
: "Rechnung"

, "Time Account, Time Accounts"
: [
  "Zeitkonto"
 ,"Zeitkonten"

]
, "Number"
: "Nummer"

, "Title"
: "Titel"

, "Access"
: "Zugang"

, "Permissions"
: "Zugriffsrechte"

, "Time Account - Billed"
: "Zeitkonto - in Rechnung"

, "not yet billed"
: "noch nicht abgerechnet"

, "to bill"
: "abzurechnen"

, "billed"
: "abgerechnet"

, "Time Account - Status"
: "Zeitkonto - Status"

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""

]
, "Book Own"
: "Eigene buchen"

, "The grant to add Timesheets to this Timeaccount"
: "Das Recht, Stundenzettel auf dieses Zeitkonto zu buchen"

, "View All"
: "Alle sehen"

, "The grant to view Timesheets of other users"
: "Das Recht Stundenzettel anderer Benutzer einzusehen"

, "Book All"
: "Alle buchen"

, "The grant to add Timesheets for other users"
: "Das Recht, Stundenzettel für andere Benutzer zu buchen"

, "Manage Clearing"
: "Abrechenbar setzen"

, "The grant to manage clearing of Timesheets"
: "Das Recht, Stundenzettel auf abgerechnet zu setzen"

, "Timeaccount Favorites"
: "Zeitkonten Favoriten"

, "Delete {0}, Delete {0}"
: [
  "Lösche {0}"
 ,"Lösche {0}"

]
, "Favorite"
: "Favorit"

, "Show closed"
: "Geschlossene anzeigen"

, "Timesheets ODS export configuration"
: "Stundenzettel ODS-Export Konfiguration"

, "Use this configuration for the timesheet ODS export."
: "Hiermit können Sie die zu verwendende ODS-Export Konfiguration einstellen."

, "A Tag which is available in context menu for fast assignment"
: "Ein Tag, das im Kontextmenü zur schnellen Zuordnung verfügbar ist"

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "Standard"

, "Enabled Features"
: "Feature aktivieren"

, "Enabled Features in Timetracker Application."
: "Feature in der Zeiterfassungs Applikation aktivieren."

, "Timeaccount Bookmarks"
: "Zeitkonten Lesezeichen"

, "none"
: "keine"

, "last week"
: "letzte Woche"

, "status to bill"
: ""

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Price"
: "Preis"

, "Cleared in"
: "Abgerechnet in"

, "Billed"
: "Abgerechnet"

, "Booking deadline"
: "Buchungsfrist"

, "Accounting time factor"
: "Faktor"

, "hour"
: "Stunde"

, "Account"
: "Benutzer"

, "Time Account (Number - Title)"
: "Zeitkonto (Nummer - Titel)"

, "Billable"
: "Abrechenbar"

, "Billable (combined)"
: "Abrechenbar (kombiniert)"

, "Cleared"
: "Abgerechnet"

, "Cleared (combined)"
: "Abgerechnet (kombiniert)"

, "Date"
: "Datum"

, "Start time"
: "Startzeit"

, "End time"
: "Endzeit"

, "Duration"
: "Dauer"

, "Need for Clarification"
: "Klärungsbedarf"

, "Accounting time"
: "Abrechenbare Zeit"

, "Workingtime is cleared"
: "Arbeitszeit ist abgerechnet"

, "Workingtime cleared in"
: "Arbeitszeit abgerechnet in"

, "Time Account closed"
: "Zeitkonto geschlossen"

, "Timetracker"
: "Zeiterfassung"

, "Timeaccounts to bill"
: "Abzurechnende Zeitkonten"

, "Timeaccounts not yet billed"
: "Nicht abgerechnete Zeitkonten"

, "Timeaccounts already billed"
: "Abgerechnete Zeitkonten"

, "My Timesheets today"
: "Meine Stundenzettel von heute"

, "My Timesheets this week"
: "Meine Stundenzettel dieser Woche"

, "My Timesheets last week"
: "Meine Stundenzettel letzter Woche"

, "My Timesheets this month"
: "Meine Stundenzettel dieses Monats"

, "My Timesheets last month"
: "Meine Stundenzettel letzten Monats"

, "Manage timeaccounts"
: "Zeitkonten verwalten"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: "Zeitkonten anlegen, bearbeiten und löschen (beinhaltet alle Stundenzettel-Rechte)"

, "Add timeaccounts"
: "Zeitkonten hinzufügen"

, "Manage shared timeaccount favorites"
: "Gemeinsame Zeitkonten-Favoriten verwalten"

, "Create or update shared timeaccount favorites"
: "Gemeinsame Zeitkonten-Favoriten erstellen oder bearbeiten"

, "Manage shared timesheet favorites"
: "Gemeinsame Stundenzettel-Favoriten verwalten"

, "Create or update shared timesheet favorites"
: "Gemeinsame Stundenzettel-Favoriten erstellen oder bearbeiten"



























, "Timesheet"
: "Stundenzettel"

, "Timeaccount"
: "Zeitkonto"

, "Time Account"
: "Zeitkonto"

, "Timeaccount Grant"
: ""

, "Delete {0}"
: "Lösche {0}"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Timetracker/js/Timetracker-lang-de-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2019-08-20 11:26+0200\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: German (http://www.transifex.com/tine20/tine20/language/de/)\nLanguage: de\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-SourceCharset: utf-8\nX-Generator: Poedit 2.0.6\n"

, "Responsible"
: "Verantwortlich"

, "without responsible"
: "ohne Verantwortlichen"

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: "Zeitkonten schließen"

, "timeframe"
: "Zeitrahmen"

, "summary"
: "Zusammenfassung"

, "Total Timesheets"
: "Alle Stundenzettel"

, "Billable Timesheets"
: "Abrechenbare Stundenzettel"

, "Total Time"
: "Gesamtsumme"

, "Time of Billable Timesheets"
: "Gesamtzeit abrechenbarer Stundenzettel"

, "Description"
: "Beschreibung"

, "Detail"
: "Detail"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: "Stundenzettel exportieren"

, "Export as ODS"
: "Als ODS exportieren"

, "Export as CSV"
: "Als CSV exportieren"

, "Export as ..."
: "Als ... exportieren"

, "Timesheet, Timesheets"
: [
  "Stundenzettel"
 ,"Stundenzettel"

]
, "Accounting"
: "Abrechnung"

, "Project time is cleared"
: "Projektzeit ist abgerechnet"

, "Project time cleared in"
: "Projektzeit abgerechnet in"

, "Project time Invoice"
: "Projektzeit Rechnung"

, "Project time billable"
: "Projektzeit ist abrechenbar"

, "Project time billable (combined)"
: "Projektzeit ist abrechenbar (kombiniert)"

, "Projecttime cleared (combined)"
: "Projektzeit ist abgerechnet (kombiniert)"

, "Timeaccount, Timeaccounts"
: [
  "Zeitkonto"
 ,"Zeitkonten"

]
, "Failed"
: "Fehlgeschlagen"

, "Could not save {0}."
: "Konnte {0} nicht speichern."

, "Booking deadline for this Timeaccount has been exceeded."
: "Die Buchungsfrist für dieses Zeitkonto wurde überschritten."

, "Closed Timeaccount Warning!"
: "Achtung, geschlossenes Zeitkonto!"

, "The selected Time Account is already closed."
: "Das ausgewählte Zeitkonto ist bereits geschlossen."

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: "Das ausgewählte Zeitkonto ist bereits geschlossen. Wollen Sie dennoch fortfahren?"

, "Contract"
: "Vertrag"

, "without contract"
: "ohne Vertrag"

, "Add New Timeaccount"
: "Zeitkonten hinzufügen"

, "Unit"
: "Einheit"

, "Unit Price"
: "Preis einer Einheit"

, "Factor"
: "Faktor"

, "Budget"
: "Budget"

, "Status"
: "Status"

, "closed"
: "geschlossen"

, "open"
: "offen"

, "Cleared In"
: "Abgerechnet in"

, "Cleared at"
: "Abgerechnet am"

, "Cost Center"
: "Kostenstelle"

, "Responsible Person"
: "Verantwortlicher"

, "Timesheets are billable"
: "Stundenzettel sind abrechenbar"

, "Invoice"
: "Rechnung"

, "Time Account, Time Accounts"
: [
  "Zeitkonto"
 ,"Zeitkonten"

]
, "Number"
: "Nummer"

, "Title"
: "Titel"

, "Access"
: "Zugang"

, "Permissions"
: "Zugriffsrechte"

, "Time Account - Billed"
: "Zeitkonto - in Rechnung"

, "not yet billed"
: "noch nicht abgerechnet"

, "to bill"
: "abzurechnen"

, "billed"
: "abgerechnet"

, "Time Account - Status"
: "Zeitkonto - Status"

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""

]
, "Book Own"
: "Eigene buchen"

, "The grant to add Timesheets to this Timeaccount"
: "Das Recht, Stundenzettel auf dieses Zeitkonto zu buchen"

, "View All"
: "Alle sehen"

, "The grant to view Timesheets of other users"
: "Das Recht Stundenzettel anderer Benutzer einzusehen"

, "Book All"
: "Alle buchen"

, "The grant to add Timesheets for other users"
: "Das Recht, Stundenzettel für andere Benutzer zu buchen"

, "Manage Clearing"
: "Abrechenbar setzen"

, "The grant to manage clearing of Timesheets"
: "Das Recht, Stundenzettel auf abgerechnet zu setzen"

, "Timeaccount Favorites"
: "Zeitkonten Favoriten"

, "Delete {0}, Delete {0}"
: [
  "Lösche {0}"
 ,"Lösche {0}"

]
, "Favorite"
: "Favorit"

, "Show closed"
: "Geschlossene anzeigen"

, "Timesheets ODS export configuration"
: "Stundenzettel ODS-Export Konfiguration"

, "Use this configuration for the timesheet ODS export."
: "Hiermit können Sie die zu verwendende ODS-Export Konfiguration einstellen."

, "A Tag which is available in context menu for fast assignment"
: "Ein Tag, das im Kontextmenü zur schnellen Zuordnung verfügbar ist"

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "Standard"

, "Enabled Features"
: "Feature aktivieren"

, "Enabled Features in Timetracker Application."
: "Feature in der Zeiterfassungs Applikation aktivieren."

, "Timeaccount Bookmarks"
: "Zeitkonten Lesezeichen"

, "none"
: "keine"

, "last week"
: "letzte Woche"

, "status to bill"
: ""

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Price"
: "Preis"

, "Cleared in"
: "Abgerechnet in"

, "Billed"
: "Abgerechnet"

, "Booking deadline"
: "Buchungsfrist"

, "Accounting time factor"
: "Faktor"

, "hour"
: "Stunde"

, "Account"
: "Benutzer"

, "Time Account (Number - Title)"
: "Zeitkonto (Nummer - Titel)"

, "Billable"
: "Abrechenbar"

, "Billable (combined)"
: "Abrechenbar (kombiniert)"

, "Cleared"
: "Abgerechnet"

, "Cleared (combined)"
: "Abgerechnet (kombiniert)"

, "Date"
: "Datum"

, "Start time"
: "Startzeit"

, "End time"
: "Endzeit"

, "Duration"
: "Dauer"

, "Need for Clarification"
: "Klärungsbedarf"

, "Accounting time"
: "Abrechenbare Zeit"

, "Workingtime is cleared"
: "Arbeitszeit ist abgerechnet"

, "Workingtime cleared in"
: "Arbeitszeit abgerechnet in"

, "Time Account closed"
: "Zeitkonto geschlossen"

, "Timetracker"
: "Zeiterfassung"

, "Timeaccounts to bill"
: "Abzurechnende Zeitkonten"

, "Timeaccounts not yet billed"
: "Nicht abgerechnete Zeitkonten"

, "Timeaccounts already billed"
: "Abgerechnete Zeitkonten"

, "My Timesheets today"
: "Meine Stundenzettel von heute"

, "My Timesheets this week"
: "Meine Stundenzettel dieser Woche"

, "My Timesheets last week"
: "Meine Stundenzettel letzter Woche"

, "My Timesheets this month"
: "Meine Stundenzettel dieses Monats"

, "My Timesheets last month"
: "Meine Stundenzettel letzten Monats"

, "Manage timeaccounts"
: "Zeitkonten verwalten"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: "Zeitkonten anlegen, bearbeiten und löschen (beinhaltet alle Stundenzettel-Rechte)"

, "Add timeaccounts"
: "Zeitkonten hinzufügen"

, "Manage shared timeaccount favorites"
: "Gemeinsame Zeitkonten-Favoriten verwalten"

, "Create or update shared timeaccount favorites"
: "Gemeinsame Zeitkonten-Favoriten erstellen oder bearbeiten"

, "Manage shared timesheet favorites"
: "Gemeinsame Stundenzettel-Favoriten verwalten"

, "Create or update shared timesheet favorites"
: "Gemeinsame Stundenzettel-Favoriten erstellen oder bearbeiten"

, "Projecttime Accounting factor"
: "Abrechnungsfaktor Projektzeit"

, "Accounting Projecttime"
: "Abrechenbare Projektzeit"

, "Select Time Account..."
: "Zeitkonto auswählen ..."

, "Start"
: "Start"

, "not set"
: "nicht gesetzt"

, "Enter description..."
: "Bitte geben Sie eine Beschreibung an..."

, "Export"
: "Export"

, "The grant to export Timesheets of Timeaccount"
: "Das Recht, Stundenzettel zu exportieren"

, "Manage All"
: "Darf Alles"

, "Includes all other grants"
: "Beinhaltet alle anderen Rechte"

, "{0}"
: "{0}"

, "Not a valid time"
: "Keine gültige Zeitangabe"

, "New Timesheet"
: "Neuer Stundenzettel"

, "Tags"
: "Tags"

, "Export Timeaccounts"
: "Zeitkonten exportieren"

, "Mass Update"
: "Massenaktualisierung"

, "Update field:"
: "Feld aktualisieren:"

, "timesheets list, timesheets lists"
: [
  "Stundenzettel-Liste"
 ,"Stundenzettel-Listen"

]
, "Quick Search"
: "Schnellsuche"

, "Last Modified Time"
: "Zuletzt geändert"

, "Last Modified By"
: "Zuletzt geändert von"

, "Creation Time"
: "Angelegt am"

, "Created By"
: "Erstellt von"

, "timeaccount list, timeaccount lists"
: [
  "Stundenzettel-Liste"
 ,"Stundenzettel-Listen"

]
, "Type"
: "Typ"

, "End"
: "Ende"

, "Working time"
: "Arbeitszeit"

, "Project time"
: "Projektzeit"

, "Timeaccounts are still in use! Are you sure you want to delete them?"
: "Zeitkonten sind noch in Benutzung!, Sind Sie sicher, dass Sie sie löschen möchten?"

, "Timesheet"
: "Stundenzettel"

, "Timeaccount"
: "Zeitkonto"

, "Time Account"
: "Zeitkonto"

, "Timeaccount Grant"
: ""

, "Delete {0}"
: "Lösche {0}"

, "timesheets list"
: "Stundenzettel-Liste"

, "timeaccount list"
: "Stundenzettel-Liste"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
